@@ -1,6 +1,5 @@
 import requests
 import parsers
-from copy import deepcopy
 
 BASE_URL_GATECH = 'https://login.gatech.edu/cas/'
 SERVICE = 'https://t-square.gatech.edu/sakai-login-tool/container'
@@ -45,7 +44,7 @@ class TSquareAPI(object):
         return _auth
 
     def __init__(self, username, password,
-                 scraper='default'):
+                 scraper='bs4'):
         """
         Initialize a TSquareAPI object.
         Logs in to TSquare with username and password.
@@ -175,7 +174,7 @@ class TSquareAPI(object):
                    the site has defined no assignments.
         """
         tools = self.get_tools(site)
-        assignment_tool_filter = [x for x in tools if x.name == 'assignments']
+        assignment_tool_filter = [x for x in tools if x.name == 'assignment-grades']
         if not assignment_tool_filter:
             return []
         assignment_tool_url = assignment_tool_filter[0].href
@@ -184,7 +183,7 @@ class TSquareAPI(object):
         iframes = self._html_iface.get_iframes(response.text)
         iframe_url = ''
         for frame in iframes:
-            if frame['title'] == 'Assignments':
+            if frame['title'] == 'Assignments ':
                 iframe_url = frame['src']
         if iframe_url == '':
             print "WARNING: NO ASSIGNMENT IFRAMES FOUND"
@@ -192,6 +191,27 @@ class TSquareAPI(object):
         response.raise_for_status()
         assignment_dict_list = self._html_iface.get_assignments(response.text)
         return [TSquareAssignment(**x) for x in assignment_dict_list]
+
+    @requires_authentication
+    def get_grades(self, site):
+        tools = self.get_tools(site)
+        grade_tool_filter = [x for x in tools if x.name == 'gradebook-tool']
+        if not grade_tool_filter:
+            return []
+        response = self._session.get(grade_tool_filter[0])
+        response.raise_for_status()
+        iframes = self._html_iface.get_iframes(response.text)
+        iframe_url = ''
+        for frame in iframes:
+            if frame['title'] == 'Gradebook ':
+                iframe_url = frame['src']
+        if iframe_url == '':
+            print "WARNING: NO GRADEBOOK IFRAMES FOUND"
+        response = self._session.get(iframe_url)
+        response.raise_for_status()
+        grade_dict_list = self._html_iface.get_grades(response.text)
+        return grade_dict_list
+        
         
 class TSquareUser:
     def __init__(self, **kwargs):
@@ -204,6 +224,9 @@ class TSquareUser:
         for key in kwargs:
             setattr(self, key, kwargs[key])
 
+        def list_attrs(self):
+            return self.__dict__.keys()
+
 class TSquareSite:
     def __init__(self, **kwargs):
         """
